@@ -49,6 +49,7 @@ type colorWriter interface {
 	reset()
 	setColors(background, foreground string)
 	setParentColors(background, foreground string)
+	clearParentColors()
 }
 
 // AnsiColor writes colorized strings
@@ -90,6 +91,10 @@ func (a *AnsiColor) setParentColors(background, foreground string) {
 	}
 }
 
+func (a *AnsiColor) clearParentColors() {
+	a.ParentColors = nil
+}
+
 // Gets the ANSI color code for a given color string.
 // This can include a valid hex color in the format `#FFFFFF`,
 // but also a name of one of the first 16 ANSI colors like `lightBlue`.
